### Name: mlogit
### Title: Multinomial logit model
### Aliases: mlogit print.mlogit suml fitted.mlogit residuals.mlogit
###   df.residual.mlogit terms.mlogit model.matrix.mlogit update.mlogit
###   summary.mlogit print.summary.mlogit vcov.mlogit logLik.mlogit
### Keywords: regression

### ** Examples


## Cameron and Trivedi's Microeconometrics p.493
## There are two alternative specific variables : pr (price) and ca (catch)
## and four fishing mode : beach, pier, boat, charter

data("Fishing", package = "mlogit")
Fish <- mlogit.data(Fishing, varying = c(4:11), shape = "wide", choice = "mode")

## a pure "conditional" model without intercepts

summary(mlogit(mode ~ pr + ca - 1, data = Fish))

## a pure "multinomial model"

summary(mlogit(mode ~ 0 | income, data = Fish))

## which can also be estimated using multinom (package nnet)

library(nnet)
summary(multinom(mode ~ income, data = Fishing))

## a "mixed" model

m <- mlogit(mode ~ pr + ca | income, data = Fish)
summary(m)

## same model with charter as the reference level

m <- mlogit(mode ~ pr + ca | income, data = Fish, reflevel = "charter")

## same model with a subset of alternatives : charter, pier, beach

m <- mlogit(mode ~ pr + ca | income, data = Fish,
            alt.subset = c("charter", "pier", "beach"))



## An heteroscedastic logit model

data("TravelMode", package = "AER")
hl <- mlogit(choice ~ wait + travel + vcost, TravelMode,
             shape = "long", id.var = "individual", alt.var = "mode",
             method = "bfgs", heterosc = TRUE, tol = 10)

## A nested logit model

TravelMode$avincome <- with(TravelMode, income * (mode == "air"))
TravelMode$time <- with(TravelMode, travel + wait)/60
TravelMode$timeair <- with(TravelMode, time * I(mode == "air"))
TravelMode$income <- with(TravelMode, income / 10)
#Heiss p.231
nl <- mlogit(choice ~ time + timeair | income, TravelMode, shape = "long",
             alt.var = "mode", print.level = 0, method = "bfgs",
             nests = list(public = c("train", "bus"), other = c("air","car")),
             tol = 1)

## a mixed logit model

rpl <- mlogit(mode ~ pr + ca | income, Fishing, varying = 4:11, shape = 'wide',
              rpar = c(pr = 'n', ca = 'n'), correlation = TRUE, halton = NA,
              R = 10, tol = 10, print.level = 0)
summary(rpl)




